advantage_timeline: Advantage Timeline

advantage_timelineR Documentation

Advantage Timeline

Description

A long format table to show who was holding which advantage/idol at what stage of the game (sog_id). This table makes it simple to perform analysis on advantages throughout the game.

Usage

advantage_timeline

Format

This data frame contains the following columns:

version

Country code for the version of the show

season

The season number

version_season

Version season key

episode

Episode

sog_id

Stage of game ID

castaway_id

Castaway ID

castaway

Castaway

advantage_id

The advantage_id key to map to the other ⁠advantage_*⁠ tables

final_n

FInal n players

holding

1 if the player is holding the advantage at this stage of the game


survivoR documentation built on May 27, 2026, 1:06 a.m.