castaway_scores: Castaway scores

castaway_scoresR Documentation

Castaway scores

Description

The challenge, vote history, and advantage scores are a measure of success or proficiency. Higher the better. See details.

Usage

castaway_scores

Format

This data frame contains the following columns:

version

Country code for the version of the show

version_season

Version season key

season

The season number

castaway_id

Castaway ID

castaway

Castaway

score_overall

Overall score for the castaway. Use this to compare players across seasons

score_outwit

Outwit score

score_outplay

Outplay score

score_outlast

Outlast score

score_result

Score based on the placing in the season

score_challenge

Score based on challenge success

score_jury

Jury score based on the proportional number of votes recieved

score_vote

Voting score for the season as a proportion of their potential max score

score_adv

Advantage score. Same as p_score_adv

score_inf

Influence score. Aim at capturing influence in the game e.g. higher the score, the higher their importance to the narrative of the episode/season

threat_challenge

Challenge threat score. Baseline is 100. Higher is better.

threat_challenge_cat

Challenge threat score positioning.

threat_strategic

Strategic threat score. Baseline is 100. Higher is better.

threat_strategic_cat

Strategic threat score positioning.

r_score_challenge

Challenge score for all challenges with weighting

r_score_chal_all

Challenge score for all challenges

r_score_chal_immunity

Challenge score for immunity challenges

r_score_chal_reward

Challenge score for reward challenges

r_score_chal_tribal

Challenge score for tribals challenges

r_score_chal_tribal_immunity

Challenge score for tribal immunity

r_score_chal_tribal_reward

Challenge score for tribal reward

r_score_chal_individual

Challenge score for individual challenges

r_score_chal_individual_immunity

Challenge score for individual immunity

r_score_chal_individual_reward

Challenge score for individual reward

r_score_chal_team

Challenge score for team challenges

r_score_chal_team_reward

Challenge score for team reward

r_score_chal_team_immunity

Challenge score for team immunity

r_score_chal_duel

Challenge score for duels

p_score_challenge

Challenge score for all challenges with weighting

p_score_chal_all

Challenge score for all challenges

p_score_chal_immunity

Challenge score for immunity challenges

p_score_chal_reward

Challenge score for reward challenges

p_score_chal_tribal

Challenge score for tribals challenges

p_score_chal_tribal_immunity

Challenge score for tribal immunity

p_score_chal_tribal_reward

Challenge score for tribal reward

p_score_chal_individual

Challenge score for individual challenges

p_score_chal_individual_immunity

Challenge score for individual immunity

p_score_chal_individual_reward

Challenge score for individual reward

p_score_chal_team

Challenge score for team challenges

p_score_chal_team_reward

Challenge score for team reward

p_score_chal_team_immunity

Challenge score for team immunity

p_score_chal_duel

Challenge score for duels

r_score_vote

Vote history score

p_score_vote

Proportional vote history score for the season

r_score_adv

Advantage score

p_score_adv

Scaled advantage score - min max bewtween 0 and 1

r_score_inf

Influence score

p_score_inf

Scaled influence score - min max bewtween 0 and 1

r_score_jury

Jury score

p_score_jury

Scaled jury score - min max bewtween 0 and 1

r_score_result

Result score

p_score_result

Scaled result score - min max bewtween 0 and 1

Details

The difference between the r_ and p_ sores is the r_ is the raw score which is the residual assuming equal probability. Higher the better. p_ is the residual converted to a probability.


survivoR documentation built on May 27, 2026, 1:06 a.m.