| advantage_timeline | R Documentation |
A long format table to show who was holding which advantage/idol at what stage
of the game (sog_id). This table makes it simple to perform analysis on
advantages throughout the game.
advantage_timeline
This data frame contains the following columns:
versionCountry code for the version of the show
seasonThe season number
version_seasonVersion season key
episodeEpisode
sog_idStage of game ID
castaway_idCastaway ID
castawayCastaway
advantage_idThe advantage_id key to map to the other advantage_* tables
final_nFInal n players
holding1 if the player is holding the advantage at this stage of the game
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.