| castaway_scores | R Documentation |
The challenge, vote history, and advantage scores are a measure of success or proficiency. Higher the better. See details.
castaway_scores
This data frame contains the following columns:
versionCountry code for the version of the show
version_seasonVersion season key
seasonThe season number
castaway_idCastaway ID
castawayCastaway
score_overallOverall score for the castaway. Use this to compare players across seasons
score_outwitOutwit score
score_outplayOutplay score
score_outlastOutlast score
score_resultScore based on the placing in the season
score_challengeScore based on challenge success
score_juryJury score based on the proportional number of votes recieved
score_voteVoting score for the season as a proportion of their potential max score
score_advAdvantage score. Same as p_score_adv
score_infInfluence score. Aim at capturing influence in the game e.g. higher the score, the higher their importance to the narrative of the episode/season
threat_challengeChallenge threat score. Baseline is 100. Higher is better.
threat_challenge_catChallenge threat score positioning.
threat_strategicStrategic threat score. Baseline is 100. Higher is better.
threat_strategic_catStrategic threat score positioning.
r_score_challengeChallenge score for all challenges with weighting
r_score_chal_allChallenge score for all challenges
r_score_chal_immunityChallenge score for immunity challenges
r_score_chal_rewardChallenge score for reward challenges
r_score_chal_tribalChallenge score for tribals challenges
r_score_chal_tribal_immunityChallenge score for tribal immunity
r_score_chal_tribal_rewardChallenge score for tribal reward
r_score_chal_individualChallenge score for individual challenges
r_score_chal_individual_immunityChallenge score for individual immunity
r_score_chal_individual_rewardChallenge score for individual reward
r_score_chal_teamChallenge score for team challenges
r_score_chal_team_rewardChallenge score for team reward
r_score_chal_team_immunityChallenge score for team immunity
r_score_chal_duelChallenge score for duels
p_score_challengeChallenge score for all challenges with weighting
p_score_chal_allChallenge score for all challenges
p_score_chal_immunityChallenge score for immunity challenges
p_score_chal_rewardChallenge score for reward challenges
p_score_chal_tribalChallenge score for tribals challenges
p_score_chal_tribal_immunityChallenge score for tribal immunity
p_score_chal_tribal_rewardChallenge score for tribal reward
p_score_chal_individualChallenge score for individual challenges
p_score_chal_individual_immunityChallenge score for individual immunity
p_score_chal_individual_rewardChallenge score for individual reward
p_score_chal_teamChallenge score for team challenges
p_score_chal_team_rewardChallenge score for team reward
p_score_chal_team_immunityChallenge score for team immunity
p_score_chal_duelChallenge score for duels
r_score_voteVote history score
p_score_voteProportional vote history score for the season
r_score_advAdvantage score
p_score_advScaled advantage score - min max bewtween 0 and 1
r_score_infInfluence score
p_score_infScaled influence score - min max bewtween 0 and 1
r_score_juryJury score
p_score_juryScaled jury score - min max bewtween 0 and 1
r_score_resultResult score
p_score_resultScaled result score - min max bewtween 0 and 1
The difference between the r_ and p_ sores is the r_ is the raw score which is the residual assuming equal probability. Higher the better.
p_ is the residual converted to a probability.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.